/* $Id: MibBrowserApplication.src,v 1.42 2001/06/26 05:51:03 aliakbar Exp $ */
/**
 * MibBrowserApplication.java    
 * Copyright (c) 1998 AdventNet, Inc. All Rights Reserved.
 * Please read the COPYRIGHTS file for more details.
 
 * ADVENTNET, INC. MAKES NO REPRESENTATIONS OR WARRANTIES
 * ABOUT THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.  ADVENTNET,
 *  INC. SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY
 * LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE
 * OR ITS DERIVATIVES.
 */

import com.adventnet.snmp.snmp2.*;
import com.adventnet.snmp.ui.*;
import com.adventnet.snmp.mibs.*;
import javax.swing.*; 
import javax.swing.event.*;
import java.util.StringTokenizer;
import java.awt.*; 
import java.awt.event.*; 
import com.sun.jimi.core.component.JimiCanvas;

/** A MIB Browser Application using the MIB Browser Bean. **/
public class MibBrowserApplication extends JFrame implements ActionListener {

    static String values[] = // stores the options
    { null, null, null, null, null, null, null,null };

    JMenuItem exitItem;

	boolean	conExitOpen = false;


	MibBrowser mbrowser;
    /** Setup the main frame and initialize MIB Browser bean **/
    public MibBrowserApplication() {
    
    super("AdventNet MibBrowser");
        
    getContentPane().setLayout(new BorderLayout());

    mbrowser = new MibBrowser();

    /**
     * You can customize the MenuBar. You can
     * Add and Remove the MenuItems from the MenuBar.
     * Exit MenuItem is added to the File Menu.
     */
	JMenuBar bar = mbrowser.getMenuBar();
	JMenu fileMenu = bar.getMenu(0);
	fileMenu.addSeparator();
	exitItem =new JMenuItem("Exit",'x');
	Font lfont=new Font("Regular",Font.PLAIN,12);
	exitItem.setFont(lfont);
	fileMenu.add(exitItem);
	exitItem.addActionListener(this);
	
	/**
     * MenuBar is an Option
     */
    mbrowser.setMenuBarVisible(true);

     /**
     * You can customize the MibBrowser ToolBar. You can
     * Add and Remove the Buttons from the ToolBar.
     * Exit Button is added to the ToolBar.
     */
    ToolBar toolbar = mbrowser.getToolBar();
    JButton button = toolbar.addButton("Exit",createImageIcon("exit.png"),"Exit MibBrowser");
    button.addActionListener(this);
	
    /**
     * To remove a button use the following method.
     *
     * Note:Use the index starting from 0. If a button
     * is removed then the indexes will be changed.
     * e.g. If you want to remove 1st and 2nd buttons
     * indexes are  0 and 0. Because if you remove first
     * button then the next button becomes the first button
     * its index become 0.
     */
    //toolbar.removeComponentAt(0);
	
    if (values[0] != null) mbrowser.setCommunity(values[0]);
    
    try {
        if (values[1] != null) mbrowser.setTargetPort(Integer.parseInt(values[1]));
        if (values[2] != null) mbrowser.setRetries(values[2]);
        if (values[3] != null) mbrowser.setTimeout(values[3]);
    } catch (NumberFormatException ex) {
        System.err.println("Invalid option: "+ex);
    } 
    
    if (values[5] != null) mbrowser.setTargetHost(values[5]);
    if (values[6] != null) {
		if(values[6].equals("v2"))
			mbrowser.setSnmpVersion( SnmpAPI.SNMP_VERSION_2C ) ;
		else if(values[6].equals("v1"))
			mbrowser.setSnmpVersion( SnmpAPI.SNMP_VERSION_1 );
		else if(values[6].equals("v3"))
			mbrowser.setSnmpVersion( SnmpAPI.SNMP_VERSION_3 );
		else {
			System.out.println("Invalid Version Number");
			System.exit(0);
		}
	}
	/**
	 * If database params are set, call the initJdbcParams or
	 * setting to load from compiled mibs by default.
	 */
	if(values[7] == null)
		mbrowser.setLoadFromCompiledMibs(true);
	else
	{
		StringTokenizer st = new StringTokenizer(values[7]," ");
		if(st.countTokens()==4)
		{
			try{	
				mbrowser.initJdbcParams(st.nextToken(),st.nextToken(),st.nextToken(),st.nextToken());
			}catch(Exception e)
			{
				System.out.println("Error in Database Params: "+e);
			}
		}	
		mbrowser.setLoadMibsFromDatabase(true);
	}
	
	WindowListener l = new WindowAdapter() {
        public void windowClosing(WindowEvent e) {
            if(!conExitOpen && confirmExit()) {
                System.exit(0);
            }
        }
    };


	this.addWindowListener(l);
	this.setIconImage((createImageIcon("logo.png")).getImage());
	this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
    getContentPane().add("Center", mbrowser);
    }

	ImageIcon createImageIcon(String names)
	{
	     JimiCanvas canvas=new JimiCanvas();
	     canvas.setImageLocation(getClass().getResource(names));
	     return new ImageIcon(canvas.getImage());
	}


    /** Get command line options and setup the MIB Browser accordingly **/    
    public static void main(String[] args) {
	

    // Take care of getting options
    String usage = "java MibBrowserApplication [-v version(v1/v2/v3)][-m MIB_files] [-c community] [-p port] [-t timeout] [-r retries] [-h host] [-db \"driverName url username password\"] ";
    String options[] = { "-c", "-p", "-r", "-t", "-m", "-h", "-v","-db" };

    ParseOptions opt = new ParseOptions(args,options,values, usage);
    if (opt.remArgs.length != 0) opt.usage_error();

        try {
        UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName());
        } catch (Exception e) {
            System.err.println("Couldn't use the system look and feel: "+ e);
        }

        MibBrowserApplication jframe = new MibBrowserApplication();

        jframe.setSize(730,500);
	centerWindow(jframe);
        jframe.setVisible(true);
        if (values[4] != null) jframe.mbrowser.setMibModules(values[4]);
        jframe.mbrowser.getMibTree().getTree().expandRow(0);

    }
    
    public void actionPerformed(ActionEvent e) {

		if(e.getActionCommand().equals("Exit")) {

			if(!conExitOpen && confirmExit()) {
				this.dispose();
				System.exit(0);
			}
		}
    }
    
    private static void centerWindow(Component win) {
	    
	    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Point screenCenter = new Point((screenSize.width/2), (screenSize.height/2));
        int x = screenCenter.x-win.getSize().width/2;
        int y = screenCenter.y-win.getSize().height/2;
        if (x < 0) x=0;
        if (y<0) y=0;
        win.setLocation( x, y);
    }

	private boolean confirmExit() {
		
		conExitOpen = true;
		int retval = JOptionPane.showConfirmDialog(this,
					"Do you want to really quit ",
					"Confirm Exit",
					JOptionPane.YES_NO_OPTION);
		
		if (retval == JOptionPane.NO_OPTION)
			conExitOpen = false;
			
		return (retval == JOptionPane.YES_OPTION);
	}
}
